/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.servlet.jetty;

import org.apithefire.servlet.server.ConnectorBuilder;
import org.mortbay.jetty.Connector;
import org.mortbay.jetty.nio.SelectChannelConnector;

/**
 * A {@link Connector} builder.
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
public class JettyConnectorBuilder implements ConnectorBuilder {
	
	private int port = DEFAULT_PORT;
	
	protected JettyConnectorBuilder() {
	}

	public ConnectorBuilder setPort(int port) {
		if (port < 1) {
			throw new IllegalArgumentException("Port < 1.");
		}
		this.port = port;
		return this;
	}
	
	/**
	 * Builds a {@link Connector}.
	 * 
	 * @return the built {@link Connector}
	 */
	public Connector build() {
		Connector connector = new SelectChannelConnector();
		
		connector.setPort(port);
		return connector;
	}
	
}