/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.servlet.jetty;

import java.net.URL;

import javax.servlet.Servlet;

import org.apithefire.servlet.RuntimeServletException;
import org.apithefire.servlet.server.ContextBuilder;
import org.apithefire.util.lang.Objects;
import org.apithefire.util.lang.Path;
import org.mortbay.jetty.servlet.Context;
import org.mortbay.jetty.servlet.ServletHolder;
import org.mortbay.jetty.webapp.WebAppContext;

/**
 * A {@link Context} builder.
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
public class JettyContextBuilder implements ContextBuilder {
	
	private static final String DUMMY_WAR = "dummy-war";
	private static final String DEFAULT_DESCRIPTOR = "DefaultDescriptor.xml";
	
	private Path path = Path.EMPTY_PATH;
	private Servlet servlet;
	
	protected JettyContextBuilder() {
	}
	
	public ContextBuilder setPath(Path path) {
		this.path = Objects.nonNull(path);
		return this;
	}

	public ContextBuilder setServlet(
			Servlet servlet) {
		this.servlet = Objects.nonNull(servlet);
		return this;
	}
	
	/**
	 * Builds a {@link Context}.
	 * 
	 * @return the built {@link Context}
	 */
	public Context build() {
		WebAppContext context = new WebAppContext();
		String contextPath = "/" + path.toString();
		URL dummyWar = getClass().getResource(DUMMY_WAR);
		URL defaultDescriptor = getClass().getResource(DEFAULT_DESCRIPTOR);
		
		context.setContextPath(contextPath);
		context.setResourceBase(dummyWar.toString());
		context.setDefaultsDescriptor(defaultDescriptor.toString());

		if (servlet == null) {
			throw new RuntimeServletException("Servlet is not set.");
		}
		context.addServlet(new ServletHolder(servlet), "/*");
		return context;
	}
	
}