/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.servlet.jetty;

import org.apithefire.servlet.server.SecureConnectorBuilder;
import org.mortbay.jetty.security.SslSocketConnector;

/**
 * A {@link SslSocketConnector} builder.
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
public class JettySecureConnectorBuilder implements
		SecureConnectorBuilder {
	
	private int port = DEFAULT_PORT;
	
	protected JettySecureConnectorBuilder() {
	}

	public SecureConnectorBuilder setPort(int port) {
		if (port < 1) {
			throw new IllegalArgumentException("Port < 1.");
		}
		this.port = port;
		return this;
	}
	
	/**
	 * Builds a {@link SslSocketConnector}.
	 * 
	 * @return the built {@link SslSocketConnector}
	 */
	public SslSocketConnector build() {
		SslSocketConnector connector = new SslSocketConnector();
		
		connector.setPort(port);
		
		// TODO: allow clients to configure these settings, these are copied
		// from jetty-ssl.xml
		connector.setMaxIdleTime(30000);
		connector.setHandshakeTimeout(2000);
		
		String keystore = getClass().getResource("keystore.bin").toString();
		String keystorePassword = "OBF:1vny1zlo1x8e1vnw1vn61x8g1zlu1vn4";
		
		connector.setKeystore(keystore);
		connector.setPassword(keystorePassword);
		connector.setKeyPassword("OBF:1u2u1wml1z7s1z7a1wnl1u2g");
		connector.setTruststore(keystore);
		connector.setTrustPassword(keystorePassword);
		return connector;
	}
	
}
