/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with this
 * work for additional information regarding copyright ownership. The ASF
 * licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apithefire.servlet.jetty;

import org.apithefire.servlet.RuntimeServletException;
import org.apithefire.servlet.server.Server;
import org.apithefire.util.lang.Objects;

/**
 * A <a href="http://www.mortbay.org/">Jetty</a> server.
 * 
 * @author <a href="mailto:bachew@gmail.com">Chew Boon Aik</a>
 */
public class JettyServer implements Server {
	
	private org.mortbay.jetty.Server server;
	
	protected JettyServer(org.mortbay.jetty.Server server) {
		this.server = Objects.nonNull(server);
	}
	
	/**
	 * Returns a new {@link JettyServerBuilder}.
	 */
	public static JettyServerBuilder newBuilder() {
		return new JettyServerBuilder();
	}

	public synchronized void start() {
		if (server == null) {
			throw new IllegalStateException("Server is closed.");
		}
		try {
			server.start();
		} catch (RuntimeException e) {
			throw e;
		} catch (Exception e) {
			throw new RuntimeServletException(e);
		}
	}

	public synchronized void join() {
		if (server != null) {
			try {
				server.join();
			} catch (InterruptedException e) {
				throw new RuntimeServletException(e);
			}
		}
	}

	public synchronized void close() {
		if (server != null) {
			try {
				server.stop();
			} catch (RuntimeException e) {
				throw e;
			} catch (Exception e) {
				throw new RuntimeServletException(e);
			}
			server = null;
		}
	}

}
